@@ -9,14 +9,15 @@ Usage::
     data: AccountSharingInfoTypeDef = {...}
     ```
 """
-from datetime import datetime
 import sys
-from typing import Dict, List
+from datetime import datetime
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -62,7 +63,6 @@ __all__ = (
     "InstanceAssociationTypeDef",
     "InstanceInformationTypeDef",
     "InstancePatchStateTypeDef",
-    "InventoryAggregatorTypeDef",
     "InventoryDeletionStatusItemTypeDef",
     "InventoryDeletionSummaryItemTypeDef",
     "InventoryDeletionSummaryTypeDef",
@@ -88,7 +88,6 @@ __all__ = (
     "MaintenanceWindowTaskTypeDef",
     "NonCompliantSummaryTypeDef",
     "NotificationConfigTypeDef",
-    "OpsAggregatorTypeDef",
     "OpsEntityItemTypeDef",
     "OpsEntityTypeDef",
     "OpsFilterTypeDef",
@@ -188,6 +187,8 @@ __all__ = (
     "DescribePatchGroupsResultTypeDef",
     "DescribePatchPropertiesResultTypeDef",
     "DescribeSessionsResponseTypeDef",
+    "InventoryAggregatorTypeDef",
+    "OpsAggregatorTypeDef",
     "DocumentFilterTypeDef",
     "DocumentKeyValuesFilterTypeDef",
     "GetAutomationExecutionResultTypeDef",
@@ -891,16 +892,6 @@ class InstancePatchStateTypeDef(
     pass
 
 
-InventoryAggregatorTypeDef = TypedDict(
-    "InventoryAggregatorTypeDef",
-    {
-        "Expression": str,
-        "Aggregators": List["InventoryAggregatorTypeDef"],
-        "Groups": List["InventoryGroupTypeDef"],
-    },
-    total=False,
-)
-
 InventoryDeletionStatusItemTypeDef = TypedDict(
     "InventoryDeletionStatusItemTypeDef",
     {
@@ -1198,19 +1189,6 @@ NotificationConfigTypeDef = TypedDict(
     total=False,
 )
 
-OpsAggregatorTypeDef = TypedDict(
-    "OpsAggregatorTypeDef",
-    {
-        "AggregatorType": str,
-        "TypeName": str,
-        "AttributeName": str,
-        "Values": Dict[str, str],
-        "Filters": List["OpsFilterTypeDef"],
-        "Aggregators": List["OpsAggregatorTypeDef"],
-    },
-    total=False,
-)
-
 OpsEntityItemTypeDef = TypedDict(
     "OpsEntityItemTypeDef", {"CaptureTime": str, "Content": List[Dict[str, str]]}, total=False
 )
@@ -2105,6 +2083,29 @@ DescribeSessionsResponseTypeDef = TypedDict(
     total=False,
 )
 
+InventoryAggregatorTypeDef = TypedDict(
+    "InventoryAggregatorTypeDef",
+    {
+        "Expression": str,
+        "Aggregators": List[Dict[str, Any]],
+        "Groups": List["InventoryGroupTypeDef"],
+    },
+    total=False,
+)
+
+OpsAggregatorTypeDef = TypedDict(
+    "OpsAggregatorTypeDef",
+    {
+        "AggregatorType": str,
+        "TypeName": str,
+        "AttributeName": str,
+        "Values": Dict[str, str],
+        "Filters": List["OpsFilterTypeDef"],
+        "Aggregators": List[Dict[str, Any]],
+    },
+    total=False,
+)
+
 DocumentFilterTypeDef = TypedDict(
     "DocumentFilterTypeDef",
     {"key": Literal["Name", "Owner", "PlatformTypes", "DocumentType"], "value": str},
